@@ -43,7 +43,7 @@ class Logger:
         # print('Logger.__init__')
 
         # Refresh rate and timer for calculating minimum interval between terminal outputs
-        self.refresh_interval = 0
+        self.refresh_interval = 0  # will be overwritten by refresh rate set below
         self.set_refresh_rate(25)
         self.t_last_update = time.time() - self.refresh_interval
 
@@ -272,9 +272,11 @@ class Logger:
                 outputs.append(self._q.get(block=False))
                 self._q.task_done()
 
-            # TBD: do the following only if outputs are there or leading line requires to be printed again --> make notify_print useful again...
-
+            # Print only if outputs had been queued or the print-request was set by any of the progbars
             if len(outputs) > 0 or self.event_print_requested.is_set():
+                # Reset event
+                self.event_print_requested.clear()
+
                 # Assemble strings for leading line
                 leading_line_done, leading_line_active = self.leading_line.get_leading_line()
 
